==> dif-database-repository-2.2.0-1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/PersistentAction.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import java.sql.Blob;
import java.util.ArrayList;
import java.util.List;

import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * PersistentAction Generated on ORM Generator DIF build process for the Model layer
 */
@SuppressWarnings("serial")
public class PersistentAction extends AbstractBeanAttributes implements java.io.Serializable {

    /** PersistentAction attributes enumeration */
    public static class Fields {

        /** actionId column */
        public static final String ACTIONID = "actionId";
        /** id column */
        public static final String ID = "id";
        /** objectAction column */
        public static final String OBJECTACTION = "objectAction";
        /** poolName column */
        public static final String POOLNAME = "poolName";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("objectAction");
            list.add("poolName");
            list.add("actionId");

            return list;
        }
    }

    /** PersistentAction FK class */
    public static class FK {
    }

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    public synchronized static List<String> getPKFieldList()
    {
        if (pkFieldList == null)
        {
            pkFieldList = new ArrayList<String>();
            pkFieldList.add("id");
        }

        return pkFieldList;
    }

    // Fields

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
    public static String getPKFieldListAsString()
    {
        StringBuffer buffer = new StringBuffer();

        for (int i = 0; i < getPKFieldList().size(); i++)
        {
            if (i != 0)
                buffer.append(",");

            buffer.append(getPKFieldList().get(i));
        }

        return buffer.toString();
    }

    /** actionId private attribute */
    private Long actionId;

    /** id private attribute */
    private Long id;

    /** objectAction private attribute */
    private Blob objectAction;

    /** poolName private attribute */
    private String poolName;

    /**
     * default constructor
     */
    public PersistentAction()
    {}

    /**
     * minimal constructor
     *
     * @param objectAction
     *            }
     */
    public PersistentAction(Blob objectAction)
    {
        this.objectAction = objectAction;
    }

    /**
     * full constructor
     *
     * @param objectAction
     * @param poolName
     * @param actionId
     */
    public PersistentAction(Blob objectAction, String poolName, Long actionId)
    {
        this.objectAction = objectAction;
        this.poolName = poolName;
        this.actionId = actionId;
    }

    // Constructors

    /**
     * Compares the String representation of the PersistentAction object
     *
     * @param other
     *            The object to compare to
     * @return true of the objects are equal
     */
    public boolean equals(PersistentAction other)
    {
        return this.toString().equals(other.toString());
    }

    /**
     * actionId getter method
     *
     * @return actionId method
     */
    public Long getActionId()
    {
        return this.actionId;
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
    @Override
    public String getAttributeAsString(String attributeName)
    {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else
        {
            return value.toString().trim();
        }
    }

    // Property accessors

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName)
    {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("objectAction".equalsIgnoreCase(attributeName))
            return objectAction;
        if ("poolName".equalsIgnoreCase(attributeName))
            return poolName;
        if ("actionId".equalsIgnoreCase(attributeName))
            return actionId;

        return null;
    }

    /**
     * id getter method
     *
     * @return id method
     */
    public Long getId()
    {
        return this.id;
    }

    /**
     * objectAction getter method
     *
     * @return objectAction method
     */
    public Blob getObjectAction()
    {
        return this.objectAction;
    }

    /**
     * poolName getter method
     *
     * @return poolName method
     */
    public String getPoolName()
    {
        return this.poolName;
    }

    /**
     * actionId setter method
     *
     * @param actionId
     * @return PersistentAction modified instance
     */
    public PersistentAction setActionId(Long actionId)
    {
        this.actionId = actionId;

        return this;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue)
    {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long) attributeValue;
        if ("objectAction".equalsIgnoreCase(attributeName))
            objectAction = (Blob) attributeValue;
        if ("poolName".equalsIgnoreCase(attributeName))
            poolName = (String) attributeValue;
        if ("actionId".equalsIgnoreCase(attributeName))
            actionId = (Long) attributeValue;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue)
    {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("poolName".equalsIgnoreCase(attributeName))
            this.poolName = attributeValue;

        if ("actionId".equalsIgnoreCase(attributeName))
            this.actionId = Long.valueOf(attributeValue);

    }

    /**
     * id setter method
     *
     * @param id
     * @return PersistentAction modified instance
     */
    public PersistentAction setId(Long id)
    {
        this.id = id;

        return this;
    }

    /**
     * objectAction setter method
     *
     * @param objectAction
     * @return PersistentAction modified instance
     */
    public PersistentAction setObjectAction(Blob objectAction)
    {
        this.objectAction = objectAction;

        return this;
    }

    /**
     * poolName setter method
     *
     * @param poolName
     * @return PersistentAction modified instance
     */
    public PersistentAction setPoolName(String poolName)
    {
        this.poolName = poolName;

        return this;
    }

    /**
     * Creates a String representation of the PersistentAction object
     *
     * @return the compiled String
     */
    public String toString()
    {
        StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");
        buffer.append("objectAction").append("='").append(getObjectAction()).append("' ");
        buffer.append("poolName").append("='").append(getPoolName()).append("' ");
        buffer.append("actionId").append("='").append(getActionId()).append("' ");
        buffer.append("]");

        return buffer.toString();
    }

}

==> dif-database-repository-2.3.1-20180413.120040-1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/PersistentAction.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.sql.Blob;
import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;

/**
 * PersistentAction
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class PersistentAction extends AbstractBeanRelationsAttributes implements java.io.Serializable {

    /** PersistentAction attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** objectAction column */
        public static final String OBJECTACTION = "objectAction";
        /** poolName column */
        public static final String POOLNAME = "poolName";
        /** actionId column */
        public static final String ACTIONID = "actionId";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("objectAction");
            list.add("poolName");
            list.add("actionId");

            return list;
        }
    }

	/**
 	 * The Class Relations.
 	 */
	 public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations {

        /**
         * Instantiates a new relations.
         *
         * @param currentPath
         *            the current path
         */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
		/**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
		/**
         * the OBJECTACTION path.
         *
         * @return the path
         */
        public String OBJECTACTION()
        {
            return buildPath(Fields.OBJECTACTION);
        }
		/**
         * the POOLNAME path.
         *
         * @return the path
         */
        public String POOLNAME()
        {
            return buildPath(Fields.POOLNAME);
        }
		/**
         * the ACTIONID path.
         *
         * @return the path
         */
        public String ACTIONID()
        {
            return buildPath(Fields.ACTIONID);
        }
    }
	
	/** The dummy obj. */
    private static PersistentAction dummyObj = new PersistentAction();

	/**
     * Get PersistentAction Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("objectAction".equalsIgnoreCase(attributeName))
            return objectAction;
        if ("poolName".equalsIgnoreCase(attributeName))
            return poolName;
        if ("actionId".equalsIgnoreCase(attributeName))
            return actionId;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("objectAction".equalsIgnoreCase(attributeName))
            objectAction = (Blob)attributeValue;
        if ("poolName".equalsIgnoreCase(attributeName))
            poolName = (String)attributeValue;
        if ("actionId".equalsIgnoreCase(attributeName))
            actionId = (Long)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** objectAction private attribute */
    private Blob objectAction;

    /** poolName private attribute */
    private String poolName;

    /** actionId private attribute */
    private Long actionId;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public PersistentAction() {
    }

	/** 
	 * minimal constructor
	 *
     * @param objectAction
    }
	 */
    public PersistentAction(Blob objectAction) {
        this.objectAction = objectAction;
    }

    /**
     * full constructor
	 *
     * @param objectAction
     * @param poolName
     * @param actionId
     */
    public PersistentAction(Blob objectAction, String poolName, Long actionId) {
        this.objectAction = objectAction;
        this.poolName = poolName;
        this.actionId = actionId;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return PersistentAction modified instance
     */
    public PersistentAction setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * objectAction getter method
     *
     * @return objectAction method
     */
    public Blob getObjectAction() {
        return this.objectAction;
    }
    
    /**       
     * objectAction setter method
     *
     * @param objectAction
     *
     * @return PersistentAction modified instance
     */
    public PersistentAction setObjectAction(Blob objectAction) {
        this.objectAction = objectAction;
        
        return this;
    }
    /**       
     * poolName getter method
     *
     * @return poolName method
     */
    public String getPoolName() {
        return this.poolName;
    }
    
    /**       
     * poolName setter method
     *
     * @param poolName
     *
     * @return PersistentAction modified instance
     */
    public PersistentAction setPoolName(String poolName) {
        this.poolName = poolName;
        
        return this;
    }
    /**       
     * actionId getter method
     *
     * @return actionId method
     */
    public Long getActionId() {
        return this.actionId;
    }
    
    /**       
     * actionId setter method
     *
     * @param actionId
     *
     * @return PersistentAction modified instance
     */
    public PersistentAction setActionId(Long actionId) {
        this.actionId = actionId;
        
        return this;
    }

    /**
     * Creates a String representation of the PersistentAction object
     *
     * @return the compiled String
     */
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("objectAction").append("='").append(getObjectAction()).append("' ");			
        buffer.append("poolName").append("='").append(getPoolName()).append("' ");			
        buffer.append("actionId").append("='").append(getActionId()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the PersistentAction object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(PersistentAction other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("poolName".equalsIgnoreCase(attributeName))
        	this.poolName = attributeValue;

        if ("actionId".equalsIgnoreCase(attributeName))
            this.actionId = Long.valueOf(attributeValue);

    }


}
